@@ -3,12 +3,9 @@ use Object::Pad;
 
 package OpenTelemetry::Trace::Span::Processor;
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
-role OpenTelemetry::Trace::Span::Processor {
+role OpenTelemetry::Trace::Span::Processor :does(OpenTelemetry::Processor) {
     method on_start;
     method on_end;
-
-    method shutdown;
-    method force_flush;
 }
